Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1642)

Unified Diff: mojo/public/cpp/bindings/connector.h

Issue 2818533003: Make nesting/running states a RunLoop rather than a MessageLoop concept. (Closed)
Patch Set: still need to check MessageLoop::current() in Mojo's RunLoopNestingObserver::GetForThread() Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « mash/quick_launch/quick_launch.cc ('k') | mojo/public/cpp/bindings/lib/connector.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: mojo/public/cpp/bindings/connector.h
diff --git a/mojo/public/cpp/bindings/connector.h b/mojo/public/cpp/bindings/connector.h
index cb065c174d7d76b0d8372ffffbb9812960de0ffe..e0bbabd33315990dc03dadfdf5eb67c89e5c9689 100644
--- a/mojo/public/cpp/bindings/connector.h
+++ b/mojo/public/cpp/bindings/connector.h
@@ -157,7 +157,7 @@ class MOJO_CPP_BINDINGS_EXPORT Connector
private:
class ActiveDispatchTracker;
- class MessageLoopNestingObserver;
+ class RunLoopNestingObserver;
// Callback of mojo::SimpleWatcher.
void OnWatcherHandleReady(MojoResult result);
@@ -218,9 +218,9 @@ class MOJO_CPP_BINDINGS_EXPORT Connector
// notification.
const char* heap_profiler_tag_ = nullptr;
- // A cached pointer to the MessageLoopNestingObserver for the MessageLoop on
- // which this Connector was created.
- MessageLoopNestingObserver* const nesting_observer_;
+ // A cached pointer to the RunLoopNestingObserver for the thread on which this
+ // Connector was created.
+ RunLoopNestingObserver* const nesting_observer_;
// |true| iff the Connector is currently dispatching a message. Used to detect
// nested dispatch operations.
« no previous file with comments | « mash/quick_launch/quick_launch.cc ('k') | mojo/public/cpp/bindings/lib/connector.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698